
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'flexwebsite/posts', {
        apiVersion: 2,
        title: 'Posts',
        icon: 'block-default',
        category: 'flex',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            number: {
                type: 'text',
                default: '',
            },
            section_id: {
                type: 'text',
                default: '',
            },
            label: {
                type: 'text',
                default: `Blog`,
            },
            title: {
                type: 'text',
                default: `Blog posts`,
            },
            subtitle: {
                type: 'text',
                default: `With our integrated CRM, project management, collaboration and invoicing capabilities, you can manage your business in one secure platform.`,
            },
            button_label: {
                type: 'text',
                default: `View All Posts`,
            }
        },
        example: { attributes: { number: '', section_id: '', label: `Blog`, title: `Blog posts`, subtitle: `With our integrated CRM, project management, collaboration and invoicing capabilities, you can manage your business in one secure platform.`, button_label: `View All Posts` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'py-16 md:py-24 lg:pb-52 bg-white', style: { backgroundImage: 'url(\'images/pattern-white.svg\')',backgroundRepeat: 'no-repeat',backgroundPosition: 'center top' }, id: propOrDefault( props.attributes.section_id, 'section_id' ) });
            const setAttributes = props.setAttributes; 
            
            
            const innerBlocksProps = null;
            
            
            return el(Fragment, {}, [
                
                        el( ServerSideRender, {
                            block: 'flexwebsite/posts',
                            httpMethod: 'POST',
                            attributes: props.attributes,
                            innerBlocksProps: innerBlocksProps,
                            blockProps: blockProps
                        } ),                        
                
                    el( InspectorControls, {},
                        [
                            
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(SelectControl, {
                                        value: props.attributes.number,
                                        label: __( 'Number of posts' ),
                                        onChange: function(val) { setAttributes({number: val}) },
                                        options: [
                                            { value: '', label: '-' },
                                            { value: '1', label: '1' },
                                            { value: '2', label: '2' },
                                            { value: '3', label: '3' },
                                            { value: '4', label: '4' },
                                            { value: '5', label: '5' },
                                            { value: '6', label: '6' },
                                            { value: '7', label: '7' },
                                            { value: '8', label: '8' },
                                            { value: '9', label: '9' },
                                            { value: '10', label: '10' },
                                            { value: '11', label: '11' },
                                            { value: '12', label: '12' }
                                        ]
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.section_id,
                                        help: __( '' ),
                                        label: __( 'Section id' ),
                                        onChange: function(val) { setAttributes({section_id: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.label,
                                        help: __( '' ),
                                        label: __( 'Label' ),
                                        onChange: function(val) { setAttributes({label: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.title,
                                        help: __( '' ),
                                        label: __( 'Title' ),
                                        onChange: function(val) { setAttributes({title: val}) },
                                        type: 'text'
                                    }),
                                    el(BaseControl, {
                                        help: __( '' ),
                                        label: __( 'Subtitle' ),
                                    }, [
                                        el(RichText, {
                                            value: props.attributes.subtitle,
                                            style: {
                                                    border: '1px solid black',
                                                    padding: '6px 8px',
                                                    minHeight: '80px',
                                                    border: '1px solid rgb(117, 117, 117)',
                                                    fontSize: '13px',
                                                    lineHeight: 'normal'
                                                },
                                            onChange: function(val) { setAttributes({subtitle: val}) },
                                        })
                                    ]),
                                    el(TextControl, {
                                        value: props.attributes.button_label,
                                        help: __( '' ),
                                        label: __( 'button_label' ),
                                        onChange: function(val) { setAttributes({button_label: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            return null;
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
