
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'flexwebsite/step', {
        apiVersion: 2,
        title: 'Step',
        icon: 'block-default',
        category: 'flex',
        parent: [ 'flexwebsite/steps' ],

        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            number: {
                type: 'text',
                default: `1`,
            },
            name: {
                type: 'text',
                default: `Custom analytics`,
            },
            description: {
                type: 'text',
                default: `Get a complete sales dashboard in the cloud. See activity, revenue and social metrics all in one place.`,
            }
        },
        example: { attributes: { number: `1`, name: `Custom analytics`, description: `Get a complete sales dashboard in the cloud. See activity, revenue and social metrics all in one place.` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'w-full md:w-1/2 px-4 mb-8' });
            const setAttributes = props.setAttributes; 
            
            
            const innerBlocksProps = null;
            
            
            return el(Fragment, {}, [
                el('div', { ...blockProps }, [el(RichText, { tagName: 'div', className: 'inline-flex items-center justify-center mb-4 w-12 h-12 text-xl text-white bg-green-500 font-semibold rounded-full', value: propOrDefault( props.attributes.number, 'number' ), onChange: function(val) { setAttributes( {number: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'h3', className: 'mb-2 text-xl font-bold', value: propOrDefault( props.attributes.name, 'name' ), onChange: function(val) { setAttributes( {name: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'p', className: 'font-medium text-coolGray-500', value: propOrDefault( props.attributes.description, 'description' ), onChange: function(val) { setAttributes( {description: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] })]),                        
                
                    el( InspectorControls, {},
                        [
                            
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.number,
                                        help: __( '' ),
                                        label: __( 'Number' ),
                                        onChange: function(val) { setAttributes({number: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.name,
                                        help: __( '' ),
                                        label: __( 'Name' ),
                                        onChange: function(val) { setAttributes({name: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.description,
                                        help: __( '' ),
                                        label: __( 'Description' ),
                                        onChange: function(val) { setAttributes({description: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'w-full md:w-1/2 px-4 mb-8' });
            return el('div', { ...blockProps }, [el(RichText.Content, { tagName: 'div', className: 'inline-flex items-center justify-center mb-4 w-12 h-12 text-xl text-white bg-green-500 font-semibold rounded-full', value: propOrDefault( props.attributes.number, 'number' ) }), el(RichText.Content, { tagName: 'h3', className: 'mb-2 text-xl font-bold', value: propOrDefault( props.attributes.name, 'name' ) }), el(RichText.Content, { tagName: 'p', className: 'font-medium text-coolGray-500', value: propOrDefault( props.attributes.description, 'description' ) })]);
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
